@@ -657,6 +657,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV_TIMELS_UART1": (0x20910061, U1),
     "CFG_MSGOUT_UBX_NAV_TIMELS_UART2": (0x20910062, U1),
     "CFG_MSGOUT_UBX_NAV_TIMELS_USB": (0x20910063, U1),
+    "CFG_MSGOUT_UBX_NAV_TIMENAVIC_I2C": (0x209106A2, U1),
+    "CFG_MSGOUT_UBX_NAV_TIMENAVIC_SPI": (0x209106A6, U1),
+    "CFG_MSGOUT_UBX_NAV_TIMENAVIC_UART1": (0x209106A3, U1),
+    "CFG_MSGOUT_UBX_NAV_TIMENAVIC_UART2": (0x209106A4, U1),
+    "CFG_MSGOUT_UBX_NAV_TIMENAVIC_USB": (0x209106A5, U1),
     "CFG_MSGOUT_UBX_NAV_TIMEQZSS_I2C": (0x20910386, U1),
     "CFG_MSGOUT_UBX_NAV_TIMEQZSS_SPI": (0x2091038A, U1),
     "CFG_MSGOUT_UBX_NAV_TIMEQZSS_UART1": (0x20910387, U1),
@@ -782,6 +787,11 @@ UBX_CONFIG_DATABASE = {
     "CFG_MSGOUT_UBX_NAV2_TIMELS_UART1": (0x20910546, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMELS_UART2": (0x20910547, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMELS_USB": (0x20910548, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMENAVIC_I2C": (0x209106A7, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMENAVIC_SPI": (0x209106AB, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMENAVIC_UART1": (0x209106A8, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMENAVIC_UART2": (0x209106A9, U1),
+    "CFG_MSGOUT_UBX_NAV2_TIMENAVIC_USB": (0x209106AA, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_I2C": (0x20910575, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_SPI": (0x20910579, U1),
     "CFG_MSGOUT_UBX_NAV2_TIMEQZSS_UART1": (0x20910576, U1),
