@@ -13,6 +13,7 @@ Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
 # pylint: disable=too-many-lines, line-too-long
 
 from pyubx2.ubxtypes_core import (
+    A250,
     A256,
     C2,
     C6,
@@ -37,6 +38,7 @@ from pyubx2.ubxtypes_core import (
     U10,
     U11,
     U12,
+    U16,
     U20,
     U22,
     U23,
@@ -136,6 +138,32 @@ UBX_PAYLOADS_GET = {
         "clkDAccOrFreqAcc": U4,
         "flags": X4,
     },
+    "AID-ALP-ACK": {
+        "acknak": U1,
+    },
+    "AID-ALP": {
+        "predTow": U4,
+        "predDur": U4,
+        "age": I4,
+        "predWno": U2,
+        "almWno": U2,
+        "reserved1": U4,
+        "svs": U1,
+        "reserved2": U1,
+        "reserved3": U1,
+        "reserved4": U1,
+    },
+    "ALP-ALPSRV": {
+        "idSize": U1,
+        "type": U1,
+        "ofs": U2,
+        "size": U2,
+        "fileId": U2,
+        "dataSize": U2,
+        "id1": U1,
+        "id2": U1,
+        "id3": U1,
+    },
     # ********************************************************************
     # Configuration Input Messages: i.e. Set Dynamic Model, Set DOP Mask, Set Baud Rate, etc..
     # Messages in the CFG class are used to configure the receiver and read out current configuration values. Any
@@ -216,12 +244,12 @@ UBX_PAYLOADS_GET = {
                 ),
                 "freq": [U4, 0.25],
                 "phaseOffset": I4,
-                "withTemp": [U4, 2 ** -8],
-                "withAge": [U4, 2 ** -8],
+                "withTemp": [U4, 2**-8],
+                "withAge": [U4, 2**-8],
                 "timeToTemp": U2,
                 "reserved3": U2,
-                "gainVco": [I4, 2 ** -16],
-                "gainUncertainty": [U1, 2 ** -8],
+                "gainVco": [I4, 2**-16],
+                "gainUncertainty": [U1, 2**-8],
                 "reserved4": U3,
             },
         ),
@@ -278,7 +306,7 @@ UBX_PAYLOADS_GET = {
     "CFG-ESFA": {
         "version": U1,
         "reserved1": U9,
-        "accelRmsThdl": [U1, 2 ** -6],
+        "accelRmsThdl": [U1, 2**-6],
         "frequency": U1,
         "latency": U2,
         "accuracy": [U2, SCAL4],
@@ -288,7 +316,7 @@ UBX_PAYLOADS_GET = {
         "version": U1,
         "reserved1": U7,
         "tcTableSaveRate": U2,
-        "gyroRmsThdl": [U1, 2 ** -8],
+        "gyroRmsThdl": [U1, 2**-8],
         "frequency": U1,
         "latency": U2,
         "accuracy": [U2, SCAL3],
@@ -374,8 +402,8 @@ UBX_PAYLOADS_GET = {
                 ),
                 "freq": [U4, 0.25],
                 "reserved2": U4,
-                "withTemp": [U4, 2 ** -8],
-                "withAge": [U4, 2 ** -8],
+                "withTemp": [U4, 2**-8],
+                "withAge": [U4, 2**-8],
                 "timeToTemp": U2,
                 "maxDevLifeTim": U2,
                 "offset": I4,
@@ -1170,16 +1198,13 @@ UBX_PAYLOADS_GET = {
     "ESF-STATUS": {
         "iTOW": U4,
         "version": U1,
-        "reserved1": U1,
-        "reserved2": U2,
-        "reserved3": U4,
-        "status": U1,
-        "reserved4": U1,
-        "reserved5": U1,
-        "numCh": U1,
+        "reserved0": U7,
+        "fusionMode": U1,
+        "reserved1": U2,
+        "numSens": U1,
         "group": (
-            "numCh",
-            {  # repeating group * numCh
+            "numSens",
+            {  # repeating group * numSens
                 "sensStatus1": (
                     X1,
                     {
@@ -1189,7 +1214,7 @@ UBX_PAYLOADS_GET = {
                     },
                 ),
                 "sensStatus2": (
-                    X2,
+                    X1,
                     {
                         "calibStatus": U2,
                         "timeStatus": U2,
@@ -1836,6 +1861,22 @@ UBX_PAYLOADS_GET = {
             },
         ),
     },
+    "MON-SYS": {
+        "msgVer": U1,
+        "bootType": U1,
+        "cpuLoad": U1,
+        "cpuLoadMax": U1,
+        "memUsage": U1,
+        "memUsageMax": U1,
+        "ioUsage": U1,
+        "ioUsageMax": U1,
+        "runTime": U4,
+        "noticeCount": U2,
+        "warnCount": U2,
+        "errorCount": U2,
+        "tempValue": I1,
+        "reserved0": U5,
+    },
     "MON-TXBUF": {
         "groupPending": (  # repeating group * 6
             6,
@@ -1971,7 +2012,7 @@ UBX_PAYLOADS_GET = {
         "pulses": I4,
         "period": I4,
         "gyroMean": [U4, SCAL2],
-        "temperature": [I2, 2 ** -8],
+        "temperature": [I2, 2**-8],
         "direction": I1,
         "calibStatus": (
             X1,
@@ -2014,16 +2055,20 @@ UBX_PAYLOADS_GET = {
             {"state": U1, "reserved1": U1},
         ),
     },
+    # NB: special handling for NAV-HPPOS* message types;
+    # private standard and high precision attributes are
+    # combined into a single public attribute in
+    # accordance with interface specification
     "NAV-HPPOSECEF": {
         "version": U1,
         "reserved0": U3,
         "iTOW": U4,
-        "ecefX": I4,
-        "ecefY": I4,
-        "ecefZ": I4,
-        "ecefXHp": [I1, SCAL1],
-        "ecefYHp": [I1, SCAL1],
-        "ecefZHp": [I1, SCAL1],
+        "_ecefX": I4,  # cm
+        "_ecefY": I4,  # cm
+        "_ecefZ": I4,  # cm
+        "_ecefXHp": [I1, SCAL1],  # mm
+        "_ecefYHp": [I1, SCAL1],  # mm
+        "_ecefZHp": [I1, SCAL1],  # mm
         "flags": (
             X1,
             {
@@ -2042,14 +2087,14 @@ UBX_PAYLOADS_GET = {
             },
         ),
         "iTOW": U4,
-        "lon": [I4, SCAL7],
-        "lat": [I4, SCAL7],
-        "height": I4,
-        "hMSL": I4,
-        "lonHp": [I1, SCAL9],
-        "latHp": [I1, SCAL9],
-        "heightHp": [I1, SCAL1],
-        "hMSLHp": [I1, SCAL1],
+        "_lon": [I4, SCAL7],
+        "_lat": [I4, SCAL7],
+        "_height": I4,  # mm
+        "_hMSL": I4,  # mm
+        "_lonHp": [I1, SCAL9],
+        "_latHp": [I1, SCAL9],
+        "_heightHp": [I1, SCAL1],  # mm
+        "_hMSLHp": [I1, SCAL1],  # mm
         "hAcc": [U4, SCAL1],
         "vAcc": [U4, SCAL1],
     },
@@ -2167,6 +2212,28 @@ UBX_PAYLOADS_GET = {
             },
         ),
     },
+    "NAV-PL": {
+        "version": U1,
+        "tmirCoeff": U1,
+        "tmirExp": I1,
+        "plPosValid": U1,
+        "plPosFrame": U1,
+        "plVelValid": U1,
+        "plVelFrame": U1,
+        "plTimeValid": U1,
+        "reserved": U4,
+        "iTOW": U4,
+        "plPos1": U4,
+        "plPos2": U4,
+        "plPos3": U4,
+        "plVel1": U4,
+        "plVel2": U4,
+        "plVel3": U4,
+        "plPosHorizOrient": U2,
+        "plVelHorizOrient": U2,
+        "plTime": U4,
+        "reserved2": U4,
+    },
     "NAV-POSECEF": {"iTOW": U4, "ecefX": I4, "ecefY": I4, "ecefZ": I4, "pAcc": U4},
     "NAV-POSLLH": {
         "iTOW": U4,
@@ -2177,6 +2244,77 @@ UBX_PAYLOADS_GET = {
         "hAcc": U4,
         "vAcc": U4,
     },
+    "NAV-PVAT": {
+        "iTOW": U4,
+        "version": U1,
+        "valid": (
+            X1,
+            {
+                "validDate": U1,
+                "validTime": U1,
+                "fullyResolved": U1,
+                "validMag": U1,
+            },
+        ),
+        "year": U2,
+        "month": U1,
+        "day": U1,
+        "hour": U1,
+        "min": U1,
+        "sec": U1,
+        "reserved0": U1,
+        "reserved1": U2,
+        "tAcc": U4,
+        "nano": I4,
+        "fixType": U1,
+        "flags": (
+            X1,
+            {
+                "gnssFixOK": U1,
+                "diffSoln": U1,
+                "reserved4": U1,
+                "vehRollValid": U1,
+                "vehPitchValid": U1,
+                "vehHeadingValid": U1,
+                "carrSoln": U2,
+            },
+        ),
+        "flags2": (
+            X1,
+            {
+                "reserved5": U5,
+                "confirmedAvai": U1,
+                "confirmedDate": U1,
+                "confirmedTime": U1,
+            },
+        ),
+        "numSV": U1,
+        "lon": [I4, SCAL7],
+        "lat": [I4, SCAL7],
+        "height": I4,
+        "hMSL": I4,
+        "hAcc": U4,
+        "vAcc": U4,
+        "velN": I4,
+        "velE": I4,
+        "velD": I4,
+        "gSpeed": I4,
+        "sAcc": U4,
+        "vehRoll": [I4, SCAL5],
+        "vehPitch": [I4, SCAL5],
+        "vehHeading": [I4, SCAL5],
+        "motHeading": [I4, SCAL5],
+        "accRoll": [U2, SCAL2],
+        "accPitch": [U2, SCAL2],
+        "accHeading": [U2, SCAL2],
+        "magDec": [I2, SCAL2],
+        "magAcc": [U2, SCAL2],
+        "errEllipseOrient": [U2, SCAL2],
+        "errEllipseMajor": U4,
+        "errEllipseMinor": U4,
+        "reserved2": U4,
+        "reserved3": U4,
+    },
     "NAV-PVT": {
         "iTOW": U4,
         "year": U2,
@@ -2651,6 +2789,22 @@ UBX_PAYLOADS_GET = {
             },
         ),
     },
+    "NAV-TIMENAVIC": {
+        "iTOW": U4,
+        "NavICTow": U4,
+        "fNavICTow": I4,
+        "NavICWno": I2,
+        "leapS": I1,
+        "valid": (
+            X1,
+            {
+                "NavICTowValid": U1,
+                "NavICWnoValid": U1,
+                "leapSValid": U1,
+            },
+        ),
+        "tAcc": U4,
+    },
     "NAV-TIMEQZSS": {
         "iTOW": U4,
         "qzssTow": U4,
@@ -2701,391 +2855,57 @@ UBX_PAYLOADS_GET = {
         "cAcc": [U4, SCAL5],
     },
     # ********************************************************************
-    # Navigation 2 Messages: i.e. Position, Speed, Time, Acceleration, Heading, DOP, SVs used.
-    # The messages in the UBX-NAV2 class are used to output navigation results and data, such as
-    # position, altitude and velocity in a number of formats, and status flags and accuracy estimate
-    # figures, or satellite and signal information. The messages are generated with the configured
-    # navigation rate.
-    "NAV2-CLOCK": {"iTOW": U4, "clkB": I4, "clkD": I4, "tAcc": U4, "fAcc": U4},
-    "NAV2-COV": {
-        "iTOW": U4,
-        "version": U1,
-        "posCovValid": U1,
-        "velCovValid": U1,
-        "reserved0": U9,
-        "posCovNN": R4,
-        "posCovNE": R4,
-        "posCovND": R4,
-        "posCovEE": R4,
-        "posCovED": R4,
-        "posCovDD": R4,
-        "velCovNN": R4,
-        "velCovNE": R4,
-        "velCovND": R4,
-        "velCovEE": R4,
-        "velCovED": R4,
-        "velCovDD": R4,
-    },
-    "NAV2-DOP": {
-        "iTOW": U4,
-        "gDOP": [U2, SCAL2],
-        "pDOP": [U2, SCAL2],
-        "tDOP": [U2, SCAL2],
-        "vDOP": [U2, SCAL2],
-        "hDOP": [U2, SCAL2],
-        "nDOP": [U2, SCAL2],
-        "eDOP": [U2, SCAL2],
-    },
-    "NAV2-EOE": {"iTOW": U4},
-    "NAV2-ODO": {
-        "version": U1,
-        "reserved0": U3,
-        "iTOW": U4,
-        "distance": U4,
-        "totalDistance": U4,
-        "distanceStd": U4,
-    },
-    "NAV2-POSECEF": {"iTOW": U4, "ecefX": I4, "ecefY": I4, "ecefZ": I4, "pAcc": U4},
-    "NAV2-POSLLH": {
-        "iTOW": U4,
-        "lon": [I4, SCAL7],
-        "lat": [I4, SCAL7],
-        "height": I4,
-        "hMSL": I4,
-        "hAcc": U4,
-        "vAcc": U4,
-    },
-    "NAV2-PVT": {
-        "iTOW": U4,
-        "year": U2,
-        "month": U1,
-        "day": U1,
-        "hour": U1,
-        "min": U1,
-        "second": U1,
-        "valid": (
-            X1,
-            {
-                "validDate": U1,
-                "validTime": U1,
-                "fullyResolved": U1,
-                "validMag": U1,
-            },
-        ),
-        "tAcc": U4,
-        "nano": I4,
-        "fixType": U1,
-        "flags": (
-            X1,
-            {
-                "gnssFixOk": U1,
-                "difSoln": U1,
-                "psmState": U3,
-                "headVehValid": U1,
-                "carrSoln": U2,
-            },
-        ),
-        "flags2": (
-            X1,
-            {
-                "reserved": U5,
-                "confirmedAvai": U1,
-                "confirmedDate": U1,
-                "confirmedTime": U1,
-            },
-        ),
-        "numSV": U1,
-        "lon": [I4, SCAL7],
-        "lat": [I4, SCAL7],
-        "height": I4,
-        "hMSL": I4,
-        "hAcc": U4,
-        "vAcc": U4,
-        "velN": I4,
-        "velE": I4,
-        "velD": I4,
-        "gSpeed": I4,
-        "headMot": [I4, SCAL5],
-        "sAcc": U4,
-        "headAcc": [U4, SCAL5],
-        "pDOP": [U2, SCAL2],
-        "flags3": (
-            X2,
-            {
-                "invalidLlh": U1,
-                "lastCorrectionAge": U4,
-            },
-        ),
-        "reserved0": U4,
-        "headVeh": [I4, SCAL5],
-        "magDec": [I2, SCAL2],
-        "magAcc": [U2, SCAL2],
-    },
-    "NAV2-SAT": {
-        "iTOW": U4,
-        "version": U1,
-        "numSvs": U1,
-        "reserved0": I1,
-        "group": (
-            "numSvs",
-            {  # repeating group * numSvs
-                "gnssId": U1,
-                "svId": U1,
-                "cno": U1,
-                "elev": I1,
-                "azim": I2,
-                "prRes": [I2, SCAL1],
-                "flags": (
-                    X4,
-                    {
-                        "qualityInd": U3,
-                        "svUsed": U1,
-                        "health": U2,
-                        "diffCorr": U1,
-                        "smoothed": U1,
-                        "orbitSource": U3,
-                        "ephAvail": U1,
-                        "almAvail": U1,
-                        "anoAvail": U1,
-                        "aopAvail": U1,
-                        "reserved13": U1,
-                        "sbasCorrUsed": U1,
-                        "rtcmCorrUsed": U1,
-                        "slasCorrUsed": U1,
-                        "spartnCorrUsed": U1,
-                        "prCorrUsed": U1,
-                        "crCorrUsed": U1,
-                        "doCorrUsed": U1,
-                    },
-                ),
-            },
-        ),
-    },
-    "NAV2-SBAS": {
-        "iTOW": U4,
-        "geo": U1,
-        "mode": U1,
-        "sys": I1,
-        "service": (
-            X1,
-            {
-                "Ranging": U1,
-                "Corrections": U1,
-                "Integrity": U1,
-                "Testmode": U1,
-                "Bad": U1,
-            },
-        ),
-        "cnt": U1,
-        "statusFlags": (
-            X1,
-            {
-                "integrityUsed": U2,
-            },
-        ),
-        "reserved0": U2,
-        "channels": (  # repeating group * cnt
-            "cnt",
-            {
-                "svid": U1,
-                "flags": U1,
-                "udre": U1,
-                "svSys": U1,
-                "svService": U1,
-                "reserved1": U1,
-                "prc": I2,
-                "reserved2": U2,
-                "ic": I2,
-            },
-        ),
-    },
-    "NAV2-SIG": {
-        "iTOW": U4,
-        "version": U1,
-        "numSigs": U1,
-        "reserved0": U2,
-        "group": (
-            "numSigs",
-            {  # repeating group * numSigs
-                "gnssId": U1,
-                "svId": U1,
-                "sigId": U1,
-                "freqId": U1,
-                "prRes": [I2, SCAL1],
-                "cno": U1,
-                "qualityInd": U1,
-                "corrSource": U1,
-                "ionoModel": U1,
-                "sigFlags": (
-                    X2,
-                    {
-                        "health": U2,
-                        "prSmoothed": U1,
-                        "prUsed": U1,
-                        "crUsed": U1,
-                        "doUsed": U1,
-                        "prCorrUsed": U1,
-                        "crCorrUsed": U1,
-                        "doCorrUsed": U1,
-                    },
-                ),
-                "reserved1": U4,
-            },
-        ),
-    },
-    "NAV2-STATUS": {
-        "iTOW": U4,
-        "gpsFix": U1,
-        "flags": (
-            X1,
-            {
-                "gpsFixOk": U1,
-                "diffSoln": U1,
-                "wknSet": U1,
-                "towSet": U1,
-            },
-        ),
-        "fixStat": (
-            X1,
-            {
-                "diffCorr": U1,
-                "carrSolnValid": U1,
-                "reserved0": U4,
-                "mapMatching": U2,
-            },
-        ),
-        "flags2": (
-            X1,
-            {
-                "psmState": U2,
-                "reserved1": U1,
-                "spoofDetState": U2,
-                "reserved2": U1,
-                "carrSoln": U2,
-            },
-        ),
-        "ttff": U4,
-        "msss": U4,
-    },
-    "NAV2-TIMEBDS": {
-        "iTOW": U4,
-        "SOW": U4,
-        "fSOW": I4,
-        "week": I2,
-        "leapS": I1,
-        "valid": (
-            X1,
-            {
-                "sowValid": U1,
-                "weekValid": U1,
-                "leapSValid": U1,
-            },
-        ),
-        "tAcc": U4,
-    },
-    "NAV2-TIMEGAL": {
-        "iTOW": U4,
-        "galTow": U4,
-        "fGalTow": I4,
-        "galWno": I2,
-        "leapS": I1,
-        "valid": (
-            X1,
-            {
-                "galTowValid": U1,
-                "galWnoValid": U1,
-                "leapSValid": U1,
-            },
-        ),
-        "tAcc": U4,
-    },
-    "NAV2-TIMEGLO": {
-        "iTOW": U4,
-        "TOD": U4,
-        "fTOD": I4,
-        "Nt": U2,
-        "N4": U1,
-        "valid": (
-            X1,
-            {
-                "todValid": U1,
-                "dateValid": U1,
-            },
-        ),
-        "tAcc": U4,
-    },
-    "NAV2-TIMEGPS": {
-        "iTOW": U4,
-        "fTOW": I4,
-        "week": I2,
-        "leapS": I1,
-        "valid": (
-            X1,
-            {
-                "towValid": U1,
-                "weekValid": U1,
-                "leapSValid": U1,
-            },
-        ),
-        "tAcc": U4,
-    },
-    "NAV2-TIMELS": {
-        "iTOW": U4,
-        "version": U1,
-        "reserved0": U3,
-        "srcOfCurrLs": U1,
-        "currLs": I1,
-        "srcOfLsChange": U1,
-        "lsChange": I1,
-        "timeToLsEvent": I4,
-        "dateOfLsGpsWn": U2,
-        "dateOfLsGpsDn": U2,
-        "reserved1": U3,
-        "valid": (
-            X1,
-            {
-                "validCurrLs": U1,
-                "validTimeToLsEvent": U1,
-            },
-        ),
-    },
-    "NAV2-TIMEUTC": {
-        "iTOW": U4,
-        "tAcc": U4,
-        "nano": I4,
-        "year": U2,
-        "month": U1,
-        "day": U1,
-        "hour": U1,
-        "min": U1,
-        "sec": U1,
-        "validflags": (
-            X1,
-            {
-                "validTOW": U1,
-                "validWKN": U1,
-                "validUTC": U1,
-                "reserved0": U1,
-                "utcStandard": U4,
-            },
-        ),
-    },
-    "NAV2-VELECEF": {"iTOW": U4, "ecefVX": I4, "ecefVY": I4, "ecefVZ": I4, "sAcc": U4},
-    "NAV2-VELNED": {
-        "iTOW": U4,
-        "velN": I4,
-        "velE": I4,
-        "velD": I4,
-        "speed": U4,
-        "gSpeed": U4,
-        "heading": [I4, SCAL5],
-        "sAcc": U4,
-        "cAcc": [U4, SCAL5],
-    },
+    #
+    # NAV2 payloads are identical to NAV and are cross-referenced in
+    # UBX_PAYLOADS_GET_NAV2 below.
+    #
     # ********************************************************************
     # Receiver Manager Messages: i.e. Satellite Status, RTC Status.
     # Messages in the RXM class are used to output status and result data from the Receiver Manager. The output
     # rate is not bound to the navigation/measurement rate and messages can also be generated on events.
+    "RXM-ALM": {
+        "svid": U4,
+        "week": U4,
+        "group": (
+            8,
+            {
+                "dwrd": U4,
+            },
+        ),
+    },
+    "RXM-COR": {
+        "version": U1,
+        "ebno": [U1, 0.125],
+        "reserved0": U2,
+        "statusInfo": (
+            X4,
+            {
+                "protocol": U5,
+                "errStatus": U2,
+                "msgUsed": U2,
+                "correctionId": U16,
+                "msgTypeValid": U1,
+                "msgSubTypeValid": U1,
+                "msgInputHandle": U1,
+                "msgEncrypted": U2,
+                "msgDecrypted": U2,
+            },
+        ),
+        "msgType": U2,
+        "msgSubType": U2,
+    },
+    "RXM-EPH": {
+        "svid": U4,
+        "how": U4,
+        "group": (
+            8,
+            {
+                "sf1d": U4,
+                "sf2d": U4,
+                "sf3d": U4,
+            },
+        ),
+    },
     "RXM-IMES": {
         "numTx": U1,
         "version": U1,
@@ -3098,7 +2918,7 @@ UBX_PAYLOADS_GET = {
                 "reserved3": U3,
                 "cno": U1,
                 "reserved4": U2,
-                "doppler": [I4, 2 ** -12],
+                "doppler": [I4, 2**-12],
                 "position1_1": (
                     X4,
                     {
@@ -3122,8 +2942,8 @@ UBX_PAYLOADS_GET = {
                         "pos2Valid": U1,
                     },
                 ),
-                "lat": [I4, 180 * 2 ** -24],
-                "lon": [I4, 360 * 2 ** -32],
+                "lat": [I4, 180 * 2**-24],
+                "lon": [I4, 360 * 2**-32],
                 "shortIdFrame": (
                     X4,
                     {
@@ -3176,7 +2996,7 @@ UBX_PAYLOADS_GET = {
                 "dopplerHz": [I4, 0.2],
                 "wholeChips": U2,
                 "fracChips": U2,
-                "codePhase": [U4, 2 ** -21],
+                "codePhase": [U4, 2**-21],
                 "intCodePhase": U1,
                 "pseuRangeRMSErr": U1,
                 "reserved4": U2,
@@ -3222,6 +3042,27 @@ UBX_PAYLOADS_GET = {
             },
         ),
     },
+    "RXM-QZSSL6": {
+        "version": U1,
+        "svId": U1,
+        "cno": [U2, 2**-8],
+        "timeTag": U4,
+        "groupDelay": U1,
+        "bitErrCorr": U1,
+        "chInfo": (
+            X2,
+            {
+                "reserved1": U8,
+                "chn": U2,
+                "msgName": U1,
+                "reserved2": U1,
+                "errStatus": U2,
+                "chName": U2,
+            },
+        ),
+        "reserved0": U2,
+        "msgBytes": A250,  # parsed as U1[250]
+    },
     "RXM-RAW": {
         "iTOW": I4,
         "week": I2,
@@ -3329,6 +3170,16 @@ UBX_PAYLOADS_GET = {
         "refStation": U2,
         "msgType": U2,
     },
+    "RXM-SFRB": {
+        "chn": U1,
+        "svid": U1,
+        "group": (
+            10,
+            {
+                "dwrd": X4,
+            },
+        ),
+    },
     "RXM-SFRBX": {
         "gnssId": U1,
         "svId": U1,
@@ -3340,6 +3191,19 @@ UBX_PAYLOADS_GET = {
         "reserved1": U1,
         "navdata": ("numWords", {"dwrd": U4}),  # repeating group * numWords
     },
+    "RXM-SPARTN": {
+        "version": U1,
+        "flags": (
+            X1,
+            {
+                "reserved1": U1,
+                "msgUsed": U2,
+            },
+        ),
+        "subType": U2,
+        "reserved0": U2,
+        "msgType": U2,
+    },
     "RXM-SVSI": {
         "iTOW": U4,
         "week": I2,
@@ -3371,6 +3235,30 @@ UBX_PAYLOADS_GET = {
             },
         ),
     },
+    "RXM-TM": {
+        "version": U1,
+        "numMeas": U1,
+        "reserved0": U2,
+        "reserved1": U4,
+        "group": (
+            "numMeas",
+            {
+                "edgeInfo": (
+                    X4,
+                    {
+                        "channel": U4,
+                        "edgeType": U1,
+                    },
+                ),
+                "count": U2,
+                "wno": U2,
+                "towMs": U4,
+                "towSubMsR": U4,
+                "reserved2": U4,
+                "reserved3": U4,
+            },
+        ),
+    },
     # ********************************************************************
     # Security Feature Messages
     # Messages in the SEC class are used for security features of the receiver.
@@ -3427,11 +3315,11 @@ UBX_PAYLOADS_GET = {
         "version": U1,
         "reserved1": U3,
         "iTOW": U4,
-        "intDeltaFreq": [I4, 2 ** -8],
-        "intDeltaFreqU": [U4, 2 ** -8],
+        "intDeltaFreq": [I4, 2**-8],
+        "intDeltaFreqU": [U4, 2**-8],
         "intRaw": U4,
-        "extDeltaFreq": [I4, 2 ** -8],
-        "extDeltaFreqU": [U4, 2 ** -8],
+        "extDeltaFreq": [I4, 2**-8],
+        "extDeltaFreqU": [U4, 2**-8],
         "extRaw": U4,
     },
     "TIM-SMEAS": {
@@ -3451,13 +3339,13 @@ UBX_PAYLOADS_GET = {
                         "phaseValid": U1,
                     },
                 ),
-                "phaseOffsetFrac": [I1, 2 ** -8],
-                "phaseUncFrac": [U1, 2 ** -8],
+                "phaseOffsetFrac": [I1, 2**-8],
+                "phaseUncFrac": [U1, 2**-8],
                 "phaseOffset": I4,
                 "phaseUnc": U4,
                 "reserved3": U4,
-                "freqOffset": [I4, 2 ** -8],
-                "freqUnc": [U4, 2 ** -8],
+                "freqOffset": [I4, 2**-8],
+                "freqUnc": [U4, 2**-8],
             },
         ),
     },
@@ -3529,14 +3417,14 @@ UBX_PAYLOADS_GET = {
         "TOW": U4,
         "gnssOffset": I4,
         "gnssUncertainty": U4,
-        "intOscOffset": [I4, 2 ** -8],
-        "intOscUncertainty": [U4, 2 ** -8],
-        "extOscOffset": [I4, 2 ** -8],
-        "extOscUncertainty": [U4, 2 ** -8],
+        "intOscOffset": [I4, 2**-8],
+        "intOscUncertainty": [U4, 2**-8],
+        "extOscOffset": [I4, 2**-8],
+        "extOscUncertainty": [U4, 2**-8],
     },
     "TIM-TP": {
         "towMS": U4,
-        "towSubMS": [U4, 2 ** -32],
+        "towSubMS": [U4, 2**-32],
         "qErr": I4,
         "week": U2,
         "flags": (
@@ -3561,8 +3449,8 @@ UBX_PAYLOADS_GET = {
         "version": U1,
         "oscId": U1,
         "reserved1": U3,
-        "gainUncertainty": [U2, 2 ** -16],
-        "gainVco": [I4, 2 ** -16],
+        "gainUncertainty": [U2, 2**-16],
+        "gainVco": [I4, 2**-16],
     },
     "TIM-VRFY": {
         "itow": I4,
@@ -3591,3 +3479,38 @@ UBX_PAYLOADS_GET = {
     # Dummy message for error testing
     "FOO-BAR": {"spam": "Z2", "eggs": "Y1"},
 }
+
+# ********************************************************************
+# Navigation 2 Messages: i.e. Position, Speed, Time, Acceleration, Heading, DOP, SVs used.
+# The messages in the UBX-NAV2 class are used to output navigation results and data, such as
+# position, altitude and velocity in a number of formats, and status flags and accuracy estimate
+# figures, or satellite and signal information. The messages are generated with the configured
+# navigation rate.
+_UBX_PAYLOADS_GET_NAV2 = {
+    "NAV2-CLOCK": UBX_PAYLOADS_GET["NAV-CLOCK"],
+    "NAV2-COV": UBX_PAYLOADS_GET["NAV-COV"],
+    "NAV2-DOP": UBX_PAYLOADS_GET["NAV-DOP"],
+    "NAV2-EELL": UBX_PAYLOADS_GET["NAV-EELL"],
+    "NAV2-EOE": UBX_PAYLOADS_GET["NAV-EOE"],
+    "NAV2-ODO": UBX_PAYLOADS_GET["NAV-ODO"],
+    "NAV2-POSECEF": UBX_PAYLOADS_GET["NAV-POSECEF"],
+    "NAV2-POSLLH": UBX_PAYLOADS_GET["NAV-POSLLH"],
+    "NAV2-PVAT": UBX_PAYLOADS_GET["NAV-PVAT"],
+    "NAV2-PVT": UBX_PAYLOADS_GET["NAV-PVT"],
+    "NAV2-SAT": UBX_PAYLOADS_GET["NAV-SAT"],
+    "NAV2-SBAS": UBX_PAYLOADS_GET["NAV-SBAS"],
+    "NAV2-SIG": UBX_PAYLOADS_GET["NAV-SIG"],
+    "NAV2-STATUS": UBX_PAYLOADS_GET["NAV-STATUS"],
+    "NAV2-TIMEBDS": UBX_PAYLOADS_GET["NAV-TIMEBDS"],
+    "NAV2-TIMEGAL": UBX_PAYLOADS_GET["NAV-TIMEGAL"],
+    "NAV2-TIMEGLO": UBX_PAYLOADS_GET["NAV-TIMEGLO"],
+    "NAV2-TIMEGPS": UBX_PAYLOADS_GET["NAV-TIMEGPS"],
+    "NAV2-TIMELS": UBX_PAYLOADS_GET["NAV-TIMELS"],
+    "NAV2-TIMENAVIC": UBX_PAYLOADS_GET["NAV-TIMENAVIC"],
+    "NAV2-TIMEUTC": UBX_PAYLOADS_GET["NAV-TIMEUTC"],
+    "NAV2-VELECEF": UBX_PAYLOADS_GET["NAV-VELECEF"],
+    "NAV2-VELNED": UBX_PAYLOADS_GET["NAV-VELNED"],
+}
+
+# Update main dictionary with NAV2 definitions
+UBX_PAYLOADS_GET.update(_UBX_PAYLOADS_GET_NAV2)
